<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar @on-reset="reset">
        <template #query>
          <QueryFilterItem>
            <SearchInput
              v-model="extraParamState.keyword"
              style="width: 200px"
              placeholder="账号/姓名/手机号"
              @on-click-search="getList"
            >
            </SearchInput>
          </QueryFilterItem>
        </template>
        <template #btn>
          <el-button @click="openDialog()" icon="Plus" type="primary">新增</el-button>
        </template>
      </ProTableQueryFilterBar>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
    <AddOrEditAccountDialog v-bind="dialogProps" />
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  ProTableQueryFilterBar,
  ProTableV2,
  SearchInput,
  LoadingLayout,
  AppContainer,
  QueryFilterItem,
  useTable,
  useFormDialog,
  defineOperationBtns,
} from '@bole-core/components';
import * as accountServices from '@/services/api/Account';
import { Message, OrderInputType } from '@bole-core/core';
import AddOrEditAccountDialog from './components/AddOrEditAccountDialog.vue';
import { formatRoleName } from '@/utils';

defineOptions({
  name: 'AccountManageList',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'changeFlag',
    name: '账号',
  },
  {
    id: '2',
    enCode: 'name',
    name: '姓名',
  },
  {
    id: '3',
    enCode: 'idNumber',
    name: '手机号',
  },
  {
    id: '4',
    enCode: 'workType',
    name: '备注',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'editBtn',
      name: '编辑',
    },
    emits: {
      onClick: (role) => openDialog(role),
    },
  },
  {
    data: {
      enCode: 'resetPasswordBtn',
      name: '重置密码',
    },
    emits: {
      onClick: (role) => handleResetPassword(),
    },
  },
]);

const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    // try {
    //   let params: API.QueryUserPageInput = {
    //     pageModel: {
    //       rows: pageSize,
    //       page: pageIndex,
    //       orderInput: extraParamState.orderInput,
    //     },
    //     searchKey: extraParamState.keyword,
    //   };
    //   let res = await userServices.getUserPage(params, {
    //     showLoading: !state.loading,
    //   });
    //   return res;
    // } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'id', order: OrderInputType.Desc }],
      keyword: '',
    },
    columnsRenderProps: {},
  }
);

function openDialog(row?: any) {
  if (row) {
    handleEdit({
      id: row.id,
      userName: row.userName,
      name: row.name,
      phoneNumber: row.phoneNumber,
      channel: row.channel,
      password: '',
      roleName: row.roleNames?.[0] ?? '',
      remark: row.remark,

      isSendMessage: row?.isSendMessage ?? false,
      sendClaimMessage: row?.sendClaimMessage ?? false,
      sendBillExpireMessage: row?.sendBillExpireMessage ?? false,
    });
  } else {
    handleAdd();
  }
}

const { dialogProps, handleAdd, handleEdit, editForm } = useFormDialog({
  onConfirm: handleAddOrEdit,
  defaultFormParams: {
    id: '',
    userName: '',
    name: '',
    phoneNumber: '',
    channel: '',
    password: '',
    roleName: '',
    remark: '',

    isSendMessage: false,
    sendClaimMessage: false,
    sendBillExpireMessage: false,
  },
});

async function handleAddOrEdit() {
  // try {
  //   let isEdit = !!editForm.id;
  //   let params: API.CreateAccountInput = {
  //     name: editForm.name,
  //     userName: editForm.userName,
  //     remark: editForm.remark,
  //     password: editForm.password,
  //     phoneNumber: editForm.phoneNumber,
  //     channel: editForm.channel,
  //     // clientId: RoleClientType.RoleBackendClientId,
  //     roleNames: [editForm.roleName],
  //   };
  //   let res;
  //   if (isEdit) {
  //     (params as API.UpdateAccountInput).id = editForm.id;
  //     res = await accountServices.updateAccount(params);
  //   } else {
  //     res = await accountServices.createAccount(params);
  //   }
  //   if (res) {
  //     Message.successMessage('操作成功');
  //     getList(isEdit ? paginationState.pageIndex : 1);
  //   }
  // } catch (error) {}
}

function handleResetPassword() {}
</script>
